NAME

Devel::DebugHooks - Hooks for perl debugger

SYNOPSIS

perl -d:DebugHooks::Terminal script.pl

## If you want to debug remotely you required additionally install IO::Async
# on remote
perl -d:DebugHooks::Server script.pl
# on local
./dclient.pl 1.2.3.4 9000

SUPPORT

Bugs may be reported via RT at

https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-DebugHooks

Support by IRC may also be found on irc.perl.org in the #debughooks channel.

AUTHOR

Eugen Konkov <debugger@konkov.top>

COPYRIGHT

The following copyright notice applies to all the files provided in this distribution, including binary files, unless explicitly noted otherwise.

Copyright (c) 2015-2026 Eugen Konkov

LICENSE

The files under lib/Devel/* in this distribution are free software; you can redistribute them and/or modify them under the same terms as Perl itself.

This free license applies only to the files under lib/Devel/*. Other files in this distribution are governed by their own licensing terms.